package rition.backend.api.v1.panel;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import rition.backend.api.v1.dto.response.AlertResponse;
import rition.backend.api.v1.dto.response.Response;
import rition.common.data.dto.PagingData;
import rition.common.data.entity.AlertEntity;
import rition.service.panel.AlertHistoryService;

@RestController
@RequestMapping("/panel/alerts")
public class AlertHistoryController {
    private final AlertHistoryService alertHistoryService;

    public AlertHistoryController(AlertHistoryService alertHistoryService) {
        this.alertHistoryService = alertHistoryService;
    }

    @GetMapping("/list")
    public Response<PagingData<AlertResponse>> getContractList(
            @RequestParam(value = "instance_id", required = false) String instanceId,
            @RequestParam(value = "page", required = false, defaultValue = "1") Integer page,
            @RequestParam(value = "page_size", required = false, defaultValue = "10") Integer pageSize
    ) {

        PagingData<AlertEntity> alertEntityPagingData = new PagingData<>(page, pageSize);
        var result = alertHistoryService.getAlertHistory(instanceId, alertEntityPagingData);

        PagingData<AlertResponse> alertResponsePagingData = PagingData.copyOnlyPagingValues(result);
        for (AlertEntity entity : result.getData()) {
            alertResponsePagingData.getData().add(AlertResponse.builder()
                    .id(entity.getId())
                    .instanceId(entity.getInstanceId())
                    .rule(entity.getRule())
                    .value(entity.getValue())
                    .time(entity.getTime().toEpochMilli())
                    .build()
            );
        }

        return Response.success(alertResponsePagingData);
    }
}
